==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Imprimir");
define("_FRIEND","Envie esta histria a um amigo");
define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_ALLOWEDHTML","HTML Permitido:");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ARTICLES","Artigos");
define("_SUBMITNEWS","Enviar Notcia");
define("_SUBMITADVICE","Por favor escreva seu artigo/histria preenchendo-o de forma correta e confira sua emisso.<br>Voc fica ciente desde j que nem todas as notcias sero publicadas.<br>Sua emisso ser conferida para ver se h erros gramaticais e talvez seja publicada no site.");
define("_SUBTITLE","Ttulo");
define("_BEDESCRIPTIVE","Seja Descritivo, Claro e Simples");
define("_BADTITLES","ttulos prejudiciais='Vejam isso!' o 'Um Artigo!'");
define("_HTMLISFINE","Voc pode usar HTML, mas cheque os URLs e os comandos HTML!");
define("_AREYOUSURE","Est seguro que incluiu um URL? Verificou sua ortografia?");
define("_SUBPREVIEW","Voc deve fazer uma Pr-Visualizao antes de poder enviar");
define("_SELECTTOPIC","Selecionar Tpico");
define("_NEWSUBPREVIEW","Pr-Visualizao da Notcia");
define("_STORYLOOK","Sua Histria se paracer com:");
define("_CHECKSTORY","Por favor confira seu texto, links, etc. antes de enviar sua histria!");
define("_THANKSSUB","Obrigado por seu envio!");
define("_SUBSENT","Seu artigo foi recebido...");
define("_SUBTEXT","Ns iremos conferir seu envio nas prximas horas, e se for algo interessante ns iremos publica-lo.");
define("_WEHAVESUB","At este momento ns possumos");
define("_WAITING","artigos que esperam ser publicados.");
define("_PREVIEW","Pr-Visualizao");
define("_NEWUSER","Novo Usurio");
define("_USCORE","Pontuao");
define("_DATE","Data");
define("_STORYTEXT","Texto da Histria");
define("_EXTENDEDTEXT","Texto Adicional");
define("_LANGUAGE","Language");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Imprimir");
define("_FRIEND","Envie esta histria a um amigo");
define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_ALLOWEDHTML","HTML Permitido:");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ARTICLES","Artigos");
define("_SUBMITNEWS","Enviar Notcia");
define("_SUBMITADVICE","Por favor escreva seu artigo/histria preenchendo-o de forma correta e confira sua emisso.<br>Voc fica ciente desde j que nem todas as notcias sero publicadas.<br>Sua emisso ser conferida para ver se h erros gramaticais e talvez seja publicada no site.");
define("_SUBTITLE","Ttulo");
define("_BEDESCRIPTIVE","Seja Descritivo, Claro e Simples");
define("_BADTITLES","ttulos prejudiciais='Vejam isso!' o 'Um Artigo!'");
define("_HTMLISFINE","Voc pode usar HTML, mas cheque os URLs e os comandos HTML!");
define("_AREYOUSURE","Est seguro que incluiu um URL? Verificou sua ortografia?");
define("_SUBPREVIEW","Voc deve fazer uma Pr-Visualizao antes de poder enviar");
define("_SELECTTOPIC","Selecionar Tpico");
define("_NEWSUBPREVIEW","Pr-Visualizao da Notcia");
define("_STORYLOOK","Sua Histria se paracer com:");
define("_CHECKSTORY","Por favor confira seu texto, links, etc. antes de enviar sua histria!");
define("_THANKSSUB","Obrigado por seu envio!");
define("_SUBSENT","Seu artigo foi recebido...");
define("_SUBTEXT","Ns iremos conferir seu envio nas prximas horas, e se for algo interessante ns iremos publica-lo.");
define("_WEHAVESUB","At este momento ns possumos");
define("_WAITING","artigos que esperam ser publicados.");
define("_PREVIEW","Pr-Visualizao");
define("_NEWUSER","Novo Usurio");
define("_USCORE","Pontuao");
define("_DATE","Data");
define("_STORYTEXT","Texto da Histria");
define("_EXTENDEDTEXT","Texto Adicional");
define("_LANGUAGE","Language");

define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
